package icu.fur93.esp32_car.page

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.navigation.NavHostController
import icu.fur93.esp32_car.Route
import icu.fur93.esp32_car.ui.component.BottomNavigationBar
import icu.fur93.esp32_car.ui.component.CardItem
import icu.fur93.esp32_car.ui.component.PageTitle
import icu.fur93.esp32_car.ui.component.StatusCard
import icu.fur93.esp32_car.ui.component.StatusCardItemText
import icu.fur93.esp32_car.ui.layout.MainLayout

@Composable
fun HomePage(navController: NavHostController) {
    MainLayout(
        content = {
            PageTitle("标题还没想好")
//            HomePageConnectedStatusCard()
            HomePageUnconnectedStatusCard()
        },
        bottomBar = {
            BottomNavigationBar(
                currentRoute = Route.Home.route,
                navController = navController
            )
        }
    )
}

@Composable
fun HomePageConnectedStatusCard() {
    StatusCard(
        cardItems = listOf(
            CardItem(
                title = "当前连接",
                content = {
                    StatusCardItemText("名称  Name")
                    StatusCardItemText("Mac  XX:XX:XX:XX:XX:XX")
                    StatusCardItemText("版本  001")
                }
            ),
            CardItem(
                title = "电机状态",
                content = {
                    LazyVerticalGrid(
                        columns = GridCells.Fixed(2)
                    ) {
                        item {
                            StatusCardItemText("A  0 1 255")
                        }
                        item {
                            StatusCardItemText("D  0 1 255")
                        }
                        item {
                            StatusCardItemText("B  1 0 255")
                        }
                        item {
                            StatusCardItemText("C  1 0 255")
                        }
                    }
                }
            ),
            CardItem(
                title = "红外模块状态",
                content = {
                    Row(
                        modifier = Modifier.fillMaxWidth(),
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        listOf(0, 0, 0, 0, 0).forEach { status ->
                            StatusCardItemText(status.toString())
                        }
                    }
                }
            ),
            CardItem(
                title = "超声波状态",
                content = {
                    Row(
                        modifier = Modifier.fillMaxWidth()
                    ) {
                        Column(Modifier.weight(1f)) {
                            StatusCardItemText("舵机角度  90")
                        }
                        Column(Modifier.weight(1f)) {
                            StatusCardItemText("舵机角度  20mm")
                        }
                    }
                }
            )
        )
    )
}

@Composable
fun HomePageUnconnectedStatusCard() {
    StatusCard(
        cardItems = listOf(
            CardItem(
                title = "设备未连接",
                content = {
                    StatusCardItemText("请先连接设备")
                }
            )
        ),
        bottomControl = {
            Button(
                onClick = {

                }
            ) {
                Text("连接设备")
            }
        }
    )
}