package icu.fur93.esp32_car.ui.component

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.Send
import androidx.compose.material.icons.filled.Home
import androidx.compose.material.icons.filled.Settings
import androidx.compose.material3.Icon
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.navigation.NavHostController
import androidx.navigation.NavOptions
import icu.fur93.esp32_car.Route

data class BottomNavigationItem(
    val title: String,
    val icon: ImageVector,
    val selectedIcon: ImageVector,
    val route: Route
)

@Composable
fun BottomNavigationBar(
    currentRoute: String,
    navController: NavHostController
) {
    val navItems = listOf(
        BottomNavigationItem(
            title = "主页",
            icon = Icons.Default.Home,
            selectedIcon = Icons.Default.Home,
            route = Route.Home
        ),
        BottomNavigationItem(
            title = "控制",
            icon = Icons.AutoMirrored.Filled.Send,
            selectedIcon = Icons.AutoMirrored.Filled.Send,
            route = Route.Control
        ),
        BottomNavigationItem(
            title = "设置",
            icon = Icons.Default.Settings,
            selectedIcon = Icons.Default.Settings,
            route = Route.Settings
        )
    )

    NavigationBar() {
        navItems.forEachIndexed{ _, item ->
            NavigationBarItem(
                icon = { Icon(if (currentRoute == item.route.route) item.selectedIcon else item.icon, item.title) },
                label = { Text(item.title) },
                selected = currentRoute == item.route.route,
                onClick = {
                    navController.navigate(item.route.route)
                }
            )
        }
    }
}